==> kubernetes-model-apps-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StatefulSetFluentImpl<A extends StatefulSetFluent<A>> extends BaseFluent<A> implements StatefulSetFluent<A>{
  public StatefulSetFluentImpl() {
  }
  public StatefulSetFluentImpl(StatefulSet instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private StatefulSetSpecBuilder spec;
  private StatefulSetStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public StatefulSetFluent.MetadataNested<A> withNewMetadata() {
    return new StatefulSetFluentImpl.MetadataNestedImpl();
  }
  public StatefulSetFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new StatefulSetFluentImpl.MetadataNestedImpl(item);
  }
  public StatefulSetFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public StatefulSetFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public StatefulSetFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StatefulSetSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StatefulSetSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StatefulSetSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StatefulSetSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public StatefulSetFluent.SpecNested<A> withNewSpec() {
    return new StatefulSetFluentImpl.SpecNestedImpl();
  }
  public StatefulSetFluent.SpecNested<A> withNewSpecLike(StatefulSetSpec item) {
    return new StatefulSetFluentImpl.SpecNestedImpl(item);
  }
  public StatefulSetFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public StatefulSetFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StatefulSetSpecBuilder().build());
  }
  public StatefulSetFluent.SpecNested<A> editOrNewSpecLike(StatefulSetSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public StatefulSetStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public StatefulSetStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(StatefulSetStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new StatefulSetStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public StatefulSetFluent.StatusNested<A> withNewStatus() {
    return new StatefulSetFluentImpl.StatusNestedImpl();
  }
  public StatefulSetFluent.StatusNested<A> withNewStatusLike(StatefulSetStatus item) {
    return new StatefulSetFluentImpl.StatusNestedImpl(item);
  }
  public StatefulSetFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public StatefulSetFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new StatefulSetStatusBuilder().build());
  }
  public StatefulSetFluent.StatusNested<A> editOrNewStatusLike(StatefulSetStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StatefulSetFluentImpl that = (StatefulSetFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<StatefulSetFluent.MetadataNested<N>> implements StatefulSetFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) StatefulSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends StatefulSetSpecFluentImpl<StatefulSetFluent.SpecNested<N>> implements StatefulSetFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StatefulSetSpec item) {
      this.builder = new StatefulSetSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StatefulSetSpecBuilder(this);
    }
    StatefulSetSpecBuilder builder;
    public N and() {
      return (N) StatefulSetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends StatefulSetStatusFluentImpl<StatefulSetFluent.StatusNested<N>> implements StatefulSetFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(StatefulSetStatus item) {
      this.builder = new StatefulSetStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new StatefulSetStatusBuilder(this);
    }
    StatefulSetStatusBuilder builder;
    public N and() {
      return (N) StatefulSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apps-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StatefulSetFluentImpl<A extends StatefulSetFluent<A>> extends BaseFluent<A> implements StatefulSetFluent<A>{
  public StatefulSetFluentImpl() {
  }
  public StatefulSetFluentImpl(StatefulSet instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private StatefulSetSpecBuilder spec;
  private StatefulSetStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public StatefulSetFluentImpl.MetadataNested<A> withNewMetadata() {
    return new StatefulSetFluentImpl.MetadataNestedImpl();
  }
  public StatefulSetFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new StatefulSetFluentImpl.MetadataNestedImpl(item);
  }
  public StatefulSetFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public StatefulSetFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public StatefulSetFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StatefulSetSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StatefulSetSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StatefulSetSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StatefulSetSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public StatefulSetFluentImpl.SpecNested<A> withNewSpec() {
    return new StatefulSetFluentImpl.SpecNestedImpl();
  }
  public StatefulSetFluentImpl.SpecNested<A> withNewSpecLike(StatefulSetSpec item) {
    return new StatefulSetFluentImpl.SpecNestedImpl(item);
  }
  public StatefulSetFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public StatefulSetFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StatefulSetSpecBuilder().build());
  }
  public StatefulSetFluentImpl.SpecNested<A> editOrNewSpecLike(StatefulSetSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public StatefulSetStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public StatefulSetStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(StatefulSetStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new StatefulSetStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public StatefulSetFluentImpl.StatusNested<A> withNewStatus() {
    return new StatefulSetFluentImpl.StatusNestedImpl();
  }
  public StatefulSetFluentImpl.StatusNested<A> withNewStatusLike(StatefulSetStatus item) {
    return new StatefulSetFluentImpl.StatusNestedImpl(item);
  }
  public StatefulSetFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public StatefulSetFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new StatefulSetStatusBuilder().build());
  }
  public StatefulSetFluentImpl.StatusNested<A> editOrNewStatusLike(StatefulSetStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StatefulSetFluentImpl that = (StatefulSetFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<StatefulSetFluentImpl.MetadataNested<N>> implements StatefulSetFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) StatefulSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends StatefulSetSpecFluentImpl<StatefulSetFluentImpl.SpecNested<N>> implements StatefulSetFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StatefulSetSpec item) {
      this.builder = new StatefulSetSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StatefulSetSpecBuilder(this);
    }
    StatefulSetSpecBuilder builder;
    public N and() {
      return (N) StatefulSetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends StatefulSetStatusFluentImpl<StatefulSetFluentImpl.StatusNested<N>> implements StatefulSetFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(StatefulSetStatus item) {
      this.builder = new StatefulSetStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new StatefulSetStatusBuilder(this);
    }
    StatefulSetStatusBuilder builder;
    public N and() {
      return (N) StatefulSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
